@@ -44,27 +44,27 @@ use_blank_slate <- function(scope = c("user", "project")) {
   scope <- match.arg(scope)
 
   if (scope == "user") { # nocov start
-    todo(
-      "To start ALL RStudio sessions with a blank slate, ",
-      "you must set this interactively, for now."
+    ui_todo(
+      "To start ALL RStudio sessions with a blank slate, \\
+      you must set this interactively, for now."
     )
-    todo(
-      "In {field('Global Options > General')}, ",
-      "do NOT check {field('Restore .RData into workspace at startup')}."
+    ui_todo(
+      "In {ui_field('Global Options > General')}, \\
+      do NOT check {ui_field('Restore .RData into workspace at startup')}."
     )
-    todo(
-      "In {field('Global Options > General')}, ",
-      "set {field('Save workspace to .RData on exit')} to {field('Never')}."
+    ui_todo(
+      "In {ui_field('Global Options > General')}, \\
+      set {ui_field('Save workspace to .RData on exit')} to {ui_value('Never')}."
     )
-    todo(
-      "Call {code('use_blank_slate(\"project\")')} to opt in to the ",
-      "blank slate workflow for a specific project."
+    ui_todo(
+      "Call {ui_code('use_blank_slate(\"project\")')} to opt in to the \\
+      blank slate workflow for a specific project."
     )
     return(invisible())
   } # nocov end
 
   if (!is_rstudio_project()) {
-    stop_glue("{value(project_name())} is not an RStudio Project.")
+    ui_stop("{ui_value(project_name())} is not an RStudio Project.")
   }
 
   rproj_fields <- modify_rproj(
@@ -89,7 +89,7 @@ is_rstudio_project <- function(base_path = proj_get()) {
 rproj_path <- function(base_path = proj_get()) {
   rproj_path <- dir_ls(base_path, regexp = "[.]Rproj$")
   if (length(rproj_path) > 1) {
-    stop_glue("Multiple .Rproj files found.")
+    ui_stop("Multiple .Rproj files found.")
   }
   if (length(rproj_path) == 1) rproj_path else NA_character_
 }
@@ -106,6 +106,10 @@ in_rstudio <- function(base_path = proj_get()) {
 
   proj <- rstudioapi::getActiveProject()
 
+  if (is.null(proj)) {
+    return(FALSE)
+  }
+
   path_real(proj) == path_real(base_path)
 }
 
@@ -146,14 +150,14 @@ restart_rstudio <- function(message = NULL) {
   }
 
   if (!is.null(message)) {
-    todo(message)
+    ui_todo(message)
   }
 
   if (!rstudioapi::hasFun("openProject")) {
     return(FALSE)
   }
 
-  if (nope(todo_bullet(), " Restart now?")) {
+  if (ui_nope("Restart now?")) {
     return(FALSE)
   }
 
