@@ -12,14 +12,29 @@ test_that("create_project() creates a non-package project", {
   expect_false(is_package(dir))
 })
 
+test_that("create functions return path to new proj, but restore active proj", {
+  path <- file_temp()
+  cur_proj <- proj_get()
+
+  new_path <- create_package(path)
+  expect_equal(proj_get(), cur_proj)
+  expect_equal(proj_path_prep(path), new_path)
+  dir_delete(path)
+
+  new_path <- create_project(path)
+  expect_equal(proj_get(), cur_proj)
+  expect_equal(proj_path_prep(path), new_path)
+  dir_delete(path)
+})
+
 test_that("nested package is disallowed, by default", {
   dir <- scoped_temporary_package()
-  expect_error(scoped_temporary_package(path(dir, "abcde")), "nested")
+  expect_error(scoped_temporary_package(path(dir, "abcde")), "anyway")
 })
 
 test_that("nested project is disallowed, by default", {
   dir <- scoped_temporary_project()
-  expect_error(scoped_temporary_project(path(dir, "abcde")), "nested")
+  expect_error(scoped_temporary_project(path(dir, "abcde")), "anyway")
 })
 
 ## https://github.com/r-lib/usethis/issues/227
@@ -27,55 +42,49 @@ test_that("create_* works w/ non-existing rel path and absolutizes it", {
   ## take care to provide a **non-absolute** path
   path_package <- path_file(file_temp(pattern = "aaa"))
   withr::with_dir(
-    path_temp(), {
-      old_project <- proj$cur
-      create_package(path_package, rstudio = FALSE, open = FALSE)
-      new_proj <- proj_get()
-      proj_set(old_project, force = TRUE, quiet = TRUE)
-    }
+    path_temp(),
+    create_package(path_package, rstudio = FALSE, open = FALSE)
   )
-  expect_true(dir_exists(new_proj))
+  expect_true(dir_exists(path_temp(path_package)))
 
   path_project <- path_file(file_temp(pattern = "aaa"))
   withr::with_dir(
-    path_temp(), {
-      old_project <- proj$cur
-      create_project(path_project, rstudio = FALSE, open = FALSE)
-      new_proj <- proj_get()
-      proj_set(old_project, force = TRUE, quiet = TRUE)
-    }
+    path_temp(),
+    create_project(path_project, rstudio = FALSE, open = FALSE)
   )
-  expect_true(dir_exists(new_proj))
+  expect_true(dir_exists(path_temp(path_project)))
 })
 
 test_that("rationalize_fork() honors fork = FALSE", {
   expect_false(
-    rationalize_fork(fork = FALSE, repo_info = list(), pat_available = TRUE)
+    rationalize_fork(fork = FALSE, repo_info = list(), auth_token = "PAT")
   )
   expect_false(
-    rationalize_fork(fork = FALSE, repo_info = list(), pat_available = FALSE)
+    rationalize_fork(fork = FALSE, repo_info = list(), auth_token = "")
   )
 })
 
-test_that("rationalize_fork() won't attempt to fork w/o PAT", {
+test_that("rationalize_fork() won't attempt to fork w/o auth_token", {
   expect_false(
-    rationalize_fork(fork = NA, repo_info = list(), pat_available = FALSE)
+    rationalize_fork(fork = NA, repo_info = list(), auth_token = "")
   )
   expect_error(
-    rationalize_fork(fork = TRUE, repo_info = list(), pat_available = FALSE),
-    "No GitHub .+auth_token.+"
+    rationalize_fork(fork = TRUE, repo_info = list(), auth_token = ""),
+    "No GitHub .+auth_token.+ is available"
   )
 })
 
 test_that("rationalize_fork() won't attempt to fork repo owned by user", {
-  expect_error(
-    rationalize_fork(
-      fork = TRUE,
-      repo_info = list(full_name = "USER/REPO", owner = list(login = "USER")),
-      pat_available = TRUE,
-      user = "USER"
-    ),
-    "Can't fork"
+  with_mock(
+    `usethis:::github_user` = function(auth_token) list(login = "USER"),
+    expect_error(
+      rationalize_fork(
+        fork = TRUE,
+        repo_info = list(full_name = "USER/REPO", owner = list(login = "USER")),
+        auth_token = "PAT"
+      ),
+      "Can't fork"
+    )
   )
 })
 
@@ -84,7 +93,7 @@ test_that("rationalize_fork() forks by default iff user cannot push", {
     rationalize_fork(
       fork = NA,
       repo_info = list(permissions = list(push = TRUE)),
-      pat_available = TRUE
+      auth_token = ""
     )
   )
   expect_true(
@@ -94,7 +103,7 @@ test_that("rationalize_fork() forks by default iff user cannot push", {
         owner = list(login = "SOMEONE_ELSE"),
         permissions = list(push = FALSE)
       ),
-      pat_available = TRUE
+      auth_token = "PAT"
     )
   )
 })
