@@ -2,6 +2,6 @@ context("use_code_of_conduct")
 
 test_that("use_code_of_conduct() creates promised file", {
   scoped_temporary_project()
-  capture_output(use_code_of_conduct())
-  expect_true(file.exists(proj_path("CODE_OF_CONDUCT.md")))
+  use_code_of_conduct()
+  expect_proj_file("CODE_OF_CONDUCT.md")
 })
