@@ -5,11 +5,10 @@ test_that("use_pkgdown() requires a package", {
   expect_error(use_pkgdown(), "not an R package")
 })
 
-test_that("use_package_doc() creates and ignores the promised file/dir", {
+test_that("use_pkgdown() creates and ignores the promised file/dir", {
   scoped_temporary_package()
-  capture_output(use_pkgdown())
-  expect_true(file.exists(proj_path("_pkgdown.yml")))
-  expect_true(dir.exists(proj_path("docs")))
+  use_pkgdown()
+  expect_proj_file("_pkgdown.yml")
   expect_true(is_build_ignored("^_pkgdown\\.yml$"))
   expect_true(is_build_ignored("^docs$"))
 })
