@@ -3,7 +3,7 @@ context("use_roxygen_md")
 test_that("use_roxygen_md() adds DESCRIPTION fields to naive package", {
   skip_if_not_installed("roxygen2")
   pkg <- scoped_temporary_package()
-  capture_output(use_roxygen_md())
+  use_roxygen_md()
   expect_identical(
     desc::desc_get("Roxygen", pkg),
     c(Roxygen = "list(markdown = TRUE)")
@@ -24,7 +24,7 @@ test_that("use_roxygen_md() does not error on a roxygen-using package", {
         file = proj_path("DESCRIPTION"),
         append = TRUE
       )
-      expect_error_free(capture_output(use_roxygen_md()))
+      expect_error_free(use_roxygen_md())
     }
   )
 })
