@@ -1,11 +1,13 @@
 context("use_template")
 
-test_that("error if try to overwrite existing file", {
-  dir <- scoped_temporary_package()
-  expect_error(
-    use_template("NEWS.md", "DESCRIPTION"),
-    "already exists"
+test_that("can leave existing file unchanged, without an error", {
+  scoped_temporary_package()
+  desc_lines_before <- readLines(proj_path("DESCRIPTION"))
+  expect_error_free(
+    use_template("NEWS.md", "DESCRIPTION")
   )
+  desc_lines_after <- readLines(proj_path("DESCRIPTION"))
+  expect_identical(desc_lines_before, desc_lines_after)
 })
 
 # helpers -----------------------------------------------------------------
